.. tfv documentation master file, created by
   sphinx-quickstart on Thu Nov  7 14:06:31 2019.

`tfv` documentation
===========
**tfv** is a suite of tools for post-processing results from `TUFLOW FV`_, a
hydrodynamic, sediment transport, water quality and particle tracking modelling software. 

The primary purpose of this page is to serve as the tfv package API Reference. Also provided are links to tutorials
and example datasets.

Installing
----------
The tfv package is available via the Python Package Index (`PyPi`_).

From command prompt install and update using pip::

   $ pip install tfv

.. End of literal block.

*Note: Version 1.0.1 has been built and tested on Python 3.9 to 3.11.

Getting Started
---------------
For tips on the setup of Python and tfv, including tutorials and examples please refer to the TUFLOW FV
`Python Tools Page`_.

API Reference
-----------------
Class reference documentation

.. toctree::
    :maxdepth: 3

   examples/index
   api_reference/index

Support
-------
For help with the tfv package contact support@tuflow.com


.. External Links
.. _TUFLOW FV: https://www.tuflow.com/Tuflow%20FV.aspx
.. _Python Tools Page: https://fvwiki.tuflow.com/index.php?title=FV_Python_Tools
.. _PyPi: https://pypi.org/project/tfv/











